rpart tree.## S3 method for class 'rpart':
labels(object, digits = 4, minlength = 1L, pretty, collapse = TRUE, ...)"rpart". This is assumed to be the
result of some function that produces an object with the same named
components as that returned by the rpart function.rpart functions that call labels
explicitly set this value, with options("digits")
as the default.0 no abbreviation is done; if 1 single English letters are
used, first lower case than upper case (with a maximum of 52
levels). If the value is greatpretty = 0 implies minlength = 0L,
pretty = NULL implies minlength = 1L, and
pretty = TRUE implies minlencollapse = TRUE (default),
the returned value is a vector of labels for the branch leading into
each node, with "root"abbreviate.collapse = TRUE) or matrix of left and
right splits (collapse = FALSE) for the supplied rpart
object. This function is called by printing methods for rpart
and is not intended to be called directly by the users.abbreviate