rpart.exp: Initialization function for exponential fitting
Description
This function does the initialization step for rpart, when the
response is a survival object. It rescales the data so as to have an
exponential baseline hazard and then uses Poisson methods. This
function would rarely if ever be called directly by a user.
Usage
rpart.exp(y, offset, parms, wt)
Arguments
y
the response, which will be of class Surv
offset
optional offset
parms
parameters controlling the fit.
This is a list with components shrink and method.
The first is the prior for the coefficient of variation of the
predictions. The second is either 'deviance'
or 'sqrt' and is the m
wt
case weights, if present
Value
a list with the necessary initialization components